@@ -1,8 +1,8 @@
 /* dbmclose.c - The the dbm file.  This is the NDBM interface. */
 
 /* This file is part of GDBM, the GNU data base manager.
-   Copyright (C) 1990, 1991, 1993, 2007, 2011 Free Software Foundation,
-   Inc.
+   Copyright (C) 1990-1991, 1993, 2007, 2011, 2017 Free Software
+   Foundation, Inc.
 
    GDBM is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
