@@ -1,5 +1,6 @@
 /* This file is part of GDBM.
-   Copyright (C) 2007, 2011, 2013, 2016 Free Software Foundation, Inc.
+   Copyright (C) 2007, 2011, 2013, 2016-2017 Free Software Foundation,
+   Inc.
 
    GDBM is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -82,7 +83,11 @@ _gdbm_internal_remap (GDBM_FILE dbf, size_t size)
   int flags = PROT_READ;
   size_t page_size = sysconf (_SC_PAGESIZE);
 
-  munmap (dbf->mapped_region, dbf->mapped_size);
+  if (dbf->mapped_region)
+    {
+      munmap (dbf->mapped_region, dbf->mapped_size);
+      dbf->mapped_region = NULL;
+    }
   dbf->mapped_size = size;
 
   if (size == 0)
