@@ -1,8 +1,8 @@
 /* version.c - This is file contains the version number for gdbm source. */
 
 /* This file is part of GDBM, the GNU data base manager.
-   Copyright (C) 1990, 1991, 1993, 2007, 2011, 2013 Free Software Foundation,
-   Inc.
+   Copyright (C) 1990-1991, 1993, 2007, 2011, 2013, 2017 Free Software
+   Foundation, Inc.
 
    GDBM is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
    The DIST_DATE magic below is replaced by the actual date when
    making the distdir. */
 const char * gdbm_version = "GDBM version " PACKAGE_VERSION ". "
-"08/08/2016"
+"11/03/2017"
 #if defined(__STDC__) && defined(__DATE__) && defined(__TIME__)
 		" (built " __DATE__ " " __TIME__ ")"
 #endif
